legitimize
===============================

version number: 0.0.1
author: Wade Williams

Overview
--------

Validate and Format Data

Installation / Usage
--------------------

To install use pip:

    $ pip install legitimize


Or clone the repo:

    $ git clone https://github.com/559wade/legitimize.git
    $ python setup.py install
    
Contributing
------------

TBD

Example
-------

TBD